@@ -404,7 +404,7 @@ class WordCloud(object):
 
         Parameters
         ----------
-        frequencies : dict from string to float
+        frequencies : dict {string: float}
             A contains words and associated frequency.
 
         max_font_size : int
@@ -535,14 +535,14 @@ class WordCloud(object):
                 # find possible places using integral image:
                 
                 ## edit
-                # if tsne_plot != None:
-                resu = tsne_plot[word]
-                to_mul_x = width/maxX
-                to_mul_y = height/maxY
-                fix_state = (to_mul_x*resu[0],to_mul_y*resu[1]) # x
-                result = occupancy.sample_position(box_size[1] + self.margin,
-                                                    box_size[0] + self.margin,
-                                                    fix_state)
+                if word in tsne_plot.keys():
+                    resu = tsne_plot[word]
+                    to_mul_x = width/maxX
+                    to_mul_y = height/maxY
+                    fix_state = (to_mul_x*resu[0],to_mul_y*resu[1]) # x
+                    result = occupancy.sample_position(box_size[1] + self.margin,
+                                                        box_size[0] + self.margin,
+                                                        fix_state)
                 # else:
                 #     result = occupancy.sample_position(box_size[1] + self.margin,
                 #                                        box_size[0] + self.margin,
@@ -604,7 +604,7 @@ class WordCloud(object):
         # print(collect_font_size)
         if plot_now:
             plt.style.use('ggplot')
-            plt.figure(figsize=(9.6,4.8))
+            plt.figure(figsize=(32,18))
             plt.imshow(self,interpolation="bilinear")
             plt.axis('off')
             plt.show()
@@ -722,7 +722,7 @@ class WordCloud(object):
             clus_i_dict = {}
             for _, row in clus_i.iterrows():
                 clus_i_dict[row['word']] = row['word_count']/row['total']
-            sorted_dict_i = sorted(clus_i_dict.items(), key=lambda item: item[1],reverse=True)[:10]
+            sorted_dict_i = sorted(clus_i_dict.items(), key=lambda item: item[1],reverse=True)
 
             lst = []
             for k,v in sorted_dict_i:
@@ -732,10 +732,11 @@ class WordCloud(object):
         return k_means_freq
 
 
-    def generate_kmeans_cloud(self, words):
+    def generate_kmeans_cloud(self, freq):
         
-        model = embed_w2v(words, lang=self.language)
-        kmeans_freq = self.gen_kmeans_frequencies(model, words, NUM_CLUSTERS=6, size_min=10,size_max=12)
+        model = embed_w2v(freq, lang=self.language)
+        kmeans_freq = self.gen_kmeans_frequencies(model, freq, NUM_CLUSTERS=6, size_min=10,size_max=12)
+        print(kmeans_freq)
 
         clouds = []
         for i in range(6):
@@ -767,7 +768,7 @@ class WordCloud(object):
         # plt.subplots_adjust(wspace=0, hspace=0)
         # plt.margins(x=0, y=0)
         plt.show()
-        
+
         return clouds
 
     def _check_generated(self):
